@@ -1,13 +1,19 @@
 # Copyright (c) 2008 Infrae. All rights reserved.
 # See also LICENSE.txt
-# $Id: __init__.py 31899 2008-11-12 10:35:19Z sylvain $
+# $Id$
 
 from zope.component import getMultiAdapter
 from AccessControl import ModuleSecurityInfo, allow_module
 from Products.Silva.ExtensionRegistry import extensionRegistry
 
+import formulator
+from Products.Formulator.FieldRegistry import FieldRegistry
+from Products.Formulator import StandardFields
+
 import install
 
+FieldRegistry.registerField(formulator.CaptchaField) # XXX fix icon
+
 def initialize(context):
     extensionRegistry.register(
         'silva.captcha', 'Silva Captcha', context, [],
