@@ -1,25 +1,21 @@
 # Copyright (c) 2008 Infrae. All rights reserved.
 # See also LICENSE.txt
-# $Id: test_service.py 31901 2008-11-12 10:42:16Z sylvain $
+# $Id$
 
 from zope.component import queryMultiAdapter
 from silva.captcha import validate
 
 from Products.Five import zcml
-from Products import Five
-zcml.load_config('meta.zcml', Five)
-zcml.load_config('configure.zcml', Five)
 
 from Products.Silva.tests import SilvaTestCase
-
-from Testing import ZopeTestCase as ztc
+from Testing.ZopeTestCase.layer import onsetup as ZopeLiteLayerSetup
+from Testing.ZopeTestCase import installProduct, installPackage
 
 
 class CaptchaTestCase(SilvaTestCase.SilvaTestCase):
     """Test case for captcha integration.
     """
 
-
     def afterSetUp(self):
         """After set up, install the extension.
         """
@@ -51,17 +47,26 @@ class CaptchaTestCase(SilvaTestCase.SilvaTestCase):
         self.failIf(root.service_extensions.is_installed('silva.captcha'))
 
 
-
-import unittest
-def test_suite():
-
-    # Load the Zope Product
-    ztc.installPackage('silva.captcha')
+@ZopeLiteLayerSetup
+def installCaptcha():
+    installPackage('silva.captcha')
 
     # Load our ZCML, which add the extension as a Product
     from silva import captcha
     zcml.load_config('configure.zcml', captcha)
 
+
+import unittest
+def test_suite():
+
+    # Install GenericSetup if it's there.
+    try:
+        import Products.GenericSetup
+        installProduct('GenericSetup')
+    except ImportError:
+        pass
+    installCaptcha()
+
     # Run tests
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(CaptchaTestCase))
